<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_GL">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Faga clic para voltar á aplicación</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Elementos</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nome de arquivo</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Volva a intentalo</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Deter</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicar Podcast en YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Encerado</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Lapis</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Fondos</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Cambiar Fondo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Páxina anterior</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PxArriba</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Páxina siguiente</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PxAbaixo</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Xestionar documentos</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Exploración web</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liña</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Liña pequena</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Liña media</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Liña grande</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Borrador</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation>Borrador pequeno</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Borrador mediano</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Borrador grande</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Cara a diante</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Volver a cargar</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Volver a cargar páxina actual</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Cargar páxina de inicio</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Mostrar favoritos</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Engadir a favoritos</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Mostrar encerado</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Borrar contido</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Mostrar preferencias</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Mostrar biblioteca</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Mostrar escritorio</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Mostrar escritorio do ordenador</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Máis grande</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Achegar</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Máis pequeno</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Afastar</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Novo cartafol</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Crear un novo cartafol</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Novo documento</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Crear un novo documento</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importar un documento</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportar un Documento</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Abrir no encerado</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Abrir a páxina no encerado</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplicar o contido seleccionado</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Eliminar o contido seleccionado</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Engadir ao documento de traballo</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Engadir o contido seleccionado ao documento aberto</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Engadir contido ao documento</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Cambiar nome</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Cambiar nome ao documento</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Mostrar Ferramentas</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multipantalla</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Tamaño ancho (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Usar tamaño ancho de documento (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Tamaño regular (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Usar tamaño regular de documento (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Tamaño personalizado</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Usar tamaño personalizado de documento</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Deter carga</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Deter carga da páxina web</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Durmir</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Poñer a presentación en modo durmir</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclado virtual</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Mostrar teclado virtual</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Fondo claro liso</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Fondo claro cuadriculado</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Fondo escuro liso</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Fondo escuro cuadriculado</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Grabar presentación en vídeo</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Iniciar grabación de pantalla</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Borrar elementos</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Borrar tódolos elementos</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Borrar anotacións</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Borrar tódalas anotacións</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Borrar páxina</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Borrar tódolos elementos</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígrafo</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Anotar documento</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Borrar anotación</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Destacar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Selector</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Seleccionar e modificar obxectos</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Man</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Desplazar páxina</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Punteiro láser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Punteiro láser virtual</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Debuxar líneas</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Escribir texto</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Captura</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturar parte da pantalla</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Engadir á páxina actual</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Engadir elemento á páxina actual</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Engadir á nova páxina</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Engadir elemento á nova páxina</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Engadir á biblioteca</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Engadir elemento á biblioteca</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Páxinas</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Crear unha nova páxina</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nova páxina</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplicar páxina</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplicar a páxina actual</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importar páxina</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importar unha páxina externa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pausar a grabación de Podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Config de podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configurar grabación de podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Captura de elemento Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Capturar contido Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Captura de contido web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Capturar contido web</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Captura personalizada</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Captura de ventana</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Capturar unha ventana</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Integrar contido web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Capturar contido web integrable</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Mostrar en pantalla</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Mostrar pantalla principal na pantalla do monitor</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Borrar tódalas anotacións</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importar simulación eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Comprobar actualizacións</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Salir de OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Ocultar OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Ocultar aplicación OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interactuar cos elementos</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Borrar o fondo</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Eliminar o fondo</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Abrir Titorial</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Abrir o titorial en páxina web</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Fondo claro con cuadrícula</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Fondo escuro con cuadrícula</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Restablecer o tamaño da cuadrícula</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Requirese autentificación</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autentificación de proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Conectar ao Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Gardar nome de usuario e contrasinal para uso futuro</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Elemento ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>O formato de destino non permite este contido</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Eliminar páxina</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>¿Está seguro de que quere eliminar 1 páxina do documento seleccionado.&apos;%0?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Tamaño de páxina</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Nova actualización dispoñible, ¿desexa visitar a páxina web?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Ningunha actualización disponible</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Actualización dispoñible</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Board drawing...</source>
        <translation type="vanished">Debuxo de encerado..</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Tamaño da cuadrícula</translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Fallo ao descargar contido %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descarga terminada</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Tipo de ferramenta descoñecida %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Tipo de contido descoñecido %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Engadir elemento</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Todos compatibles (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Borrar a páxina %1 do documento</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Páxina %1 eliminada</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Tódalas operacións con ficheiros fallaron. Erro ao copiar os ficheiros</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Agrupar</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Desagrupar</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Gardando documento...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Acaba de gardarse o documento...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>Borrando páxina %1</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Error ao engadir a imaxe á biblioteca</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Imaxe capturada</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Cargando páxina (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Almacenar propiedades en caché</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturar parte da pantalla</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Capturar a pantalla</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Mostrar a paleta do lapis</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Mostrar o encerado na pantalla secundaria</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Mostrar escritorio na pantalla secundaria</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Mostrar OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Novo cartafol</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Páxina %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Engadir cartafol de imaxes</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Engadir imaxes</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Engadir páxina dende arquivo</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplicando documento %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Documento %1 copiado</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Eliminar páxina</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Eliminar documento</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">¿Está seguro de que desexa eliminar o documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Baleirar papeleira</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">¿Está seguro de que desexa baleirar a papeleira?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Baleirando papeleira</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Papelera baleirada</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Eliminar cartafol</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">¿Está seturo de que desexa eliminar o cartafol &apos;%1&apos; e todo o seu contido?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">¡Ningún documento seleccionado!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Abrir arquivo compatible</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importando arquivo %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Fallo ao importar arquivo ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importar tódalas imaxes dende o cartafol</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Baleirar</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papeleira</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Abrir documento</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Engadir tódalas imaxes ao documento</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Tódalas imaxes (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>¡A selección non contén ningún arquivo de imaxes!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>¿Está seguro de que desexa eliminar %n páxina(s) do documento seleccionado &apos;%1&apos;?</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>O cartafol non contén ningún ficheiro con imaxes</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documentos sen título</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>O documento &apos;%1&apos; foi xerado cunha nova versión de OpenBoard (%2). Ao abrilo, pode perder información. Desexa continuar?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Está seguro de querer eliminar tódolos documentos seleccionados? </translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Eliminar varios documentos</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation>
            <numerusform>%1 páxina copiada</numerusform>
            <numerusform>%1 páxinas copiadas</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>borrar o elemento</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>¿Está seguro de que desexa eliminar els elements seleccionats?</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>Páxina de título</translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>Obxectos</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Tódolos arquivos compatibles (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Arquivo %1 gardado</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Inserindo páxina %1 de %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importación correcta</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>O arquivo %1 importouse correctamente</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importando o ficheiro %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Páxina %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>substituír</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation>O nome %1 xa está en uso.
Manter este nome sustituirá o documento.
Proporcionar un novo nome creará un novo documento.</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation>Os meus documentos</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papeleira</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 páxina copiada</numerusform>
            <numerusform>%1 páxinas copiadas</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 páxina copiada</numerusform>
            <numerusform>%1 páxinas copiadas</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>borrar o elemento</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>¿Está seguro que desexa eliminar o/s elemento(s) seleccionado(s) ?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Copiando páxina %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (copia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Copiando páxina %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 páxinas copiadas</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Descargando arquivos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation>Páxina %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Páxina %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Apareceron advertencias durante a exportación</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Fallou a exportación</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>Non foi posible exportar ao lugar seleccionado. Non ten os permisos necesarios para gardar o ficheiro</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Fallou a exportación: non se pode escribir no lugar seleccionado</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exportar a IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportar como ficheiro IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fallo na exportación</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Páxina</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportar como arquivo UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exportando %1 %2 de %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Exportar ao formato OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation>Fallo na exportación...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>Exportar como arquivo UBX</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fallo na exportación</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>Exportar ao formato OpenBoard UBX</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportar como arquivo PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportar a PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportar como arquivo PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exportando páxina %1 de %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportación a PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Páxina</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportar como datos web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fallo da exportación.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportar ao explorador web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Engadir á páxina</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Definir como fondo</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Engadir á biblioteca</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Información do obxecto</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Engadir a favoritos</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Compartir</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Regresar ao cartafol</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Eliminar de favoritos</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Crear novo cartafol</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Comprobar os ficheiros do sistema</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Imaxe importada</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Ficheiros de Audio</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Películas</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>Animacións</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interactividades</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplicacións</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Formas</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Búsqueda Web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papeleira</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Introduza un novo nome para o cartafol</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Cargando </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible en pantalla extendida</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible en pantalla extendida</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Ir á fonte de contido</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Definir como fondo</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Non se puido resolver o recurso multimedia</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Formato multimedia non soportado</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Servizo de reprodución multimedia non atopado</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Erro multimedia:</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Teclear Texto aquí&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Cor de texto</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Editable</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Cargando...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Conxelado</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformar como ferramenta</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Formato de arquivo común (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importando arquivo %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Fallo na importanción do arquivo %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importación satisfactoria.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Fallo da importación.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importando arquivo %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importación satisfactoria.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Fallo da importación do arquivo %1.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation>Openboard (conxunto de documentos) (*.ubx)</translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Formato de imaxe (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Formato de documento portátil (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Fallo da importación de PDF.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importando páxina %1 de %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Produciuse un erro ao publicar vídeo na intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publicación na Intranet en progreso %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publicar</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Entrar</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduza o nome de usuario e o contrasinal para &quot;%1&quot; en %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Fallo ao iniciar sesión en proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Errores SSL: %1 %2 ¿Desexa ignorar estos erros para este servidor?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Borrados Documentos Open-Sankore</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Mostrar este panel a próxima vez</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Sempre pode acceder ao importador de documentos OpenBoard a través do panel Preferencias na lapela Sobre. Aviso, se xa importou os seus datos Open-Sankore, pode perder documentos OpenBoard actuais</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Os documentos de Open-Sankoré do seu computador. É posible importalos a OpenBoard premendo no botón &quot;Continuar&quot; da aplicación importadora.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(copiar)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Pérdida de documentos do Repositorio</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">perdeu o acceso ao repositorio de documentos &apos;%1&apos;. Desafortunadamente, a aplicación debe pecharse para evitar a corrrupción de datos. Tamén se poden perder os últimos cambios. </translation>
    </message>
    <message>
        <source>Moving page to trash folder...</source>
        <translation type="vanished">Mover a páxina ao lixo</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation>OpenBoard perdeu o acceso ao repositorio de documentos &apos;%1&apos;. Desafortunadamente, a aplicación debe pecharse para evitar a corrrupción de datos. Tamén se poden perder os últimos cambios. </translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francés</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Francés-Suizo</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Fallo ao iniciar o codificador...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Ningún condificador de Podcast dispoñible...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Parte %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>no seu escritorio...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>en cartafol %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast creado %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Erro na grabación de podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Entrada de audio predeterminada</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Ningunha grabación de audio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publicar na Intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publicar en Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versión:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>O marcador é sensible á presión</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Inicio de sesión en proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nome de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Contrasinal:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publicar documento na web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Título:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descripción:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publicar</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>As miñas películas</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Visible a próxima vez</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Xerando miniaturas de previsualización...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniaturas xeradas...</translation>
    </message>
    <message>
        <source>loading thumbnail of page %1</source>
        <translation type="vanished">cargando miniaturas da páxina %1</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>Páxina %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Máscara</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Regla</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Compás</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Transportador</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Triángulo</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Caché</translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Páxina completa</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Actualizador de documento</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> los arquivos requiren unha actualización.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Ruta da copia de seguridade:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Seleccione un cartafol para a copia de seguridade</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>¡Actualización de arquivos satisfactoria!
Por favor, reinicie a aplicación para acceder aos documentos actualizados.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Ocurriu un erro durante a actualización. Os archivos no foron afectados.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultados de la actualización de arquivos</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Actualizando arquivo</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Por favor espere, o proceso de importación comenzará pronto...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recordamo máis tarde</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 chamado (método=%1, estado=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Fallo na autentificación de YouTube.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Error ao cargar o vídeo a YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Carga de YoutTube en progreso %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Autos &amp; Vehículos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Mascotas &amp; Animais</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Deportes</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Viaxes &amp; Eventos</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Xogo</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Comedia</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Persoas &amp; Blogs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Novas &amp; Política</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Entretemento</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Educación</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Howto &amp; estilo</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Sen ánimo de lucro &amp; Activismo</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Ciencia &amp; Tecnoloxía</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Gardar arquivo</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Descarga cancelada: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Erro ao abrir o arquivo gardado: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Erro ao gardar: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erro de rede: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 restante</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 de %2 (%3/seg) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Detido</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Descarga</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Descargas</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Anteriormente hoxe</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 elementos</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nova &amp;Lapela</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Duplicar Lapela</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Pechar Lapela</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Pechar &amp; Outras Lapelas</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recargar Lapela</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Volver a cargar tódalas lapelas</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Lapelas pechadas recentemente</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Sen título)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Ningunha búsqueda recente</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Búsquedas recentes</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Borrar búsquedas recentes</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Engadir ao documento actual</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Erro ao cargar páxina: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Descargar documento PDF: prefererías descargar o arquivo PDF ou engadilo ao documento actual de OpenBoard? </translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Abrir en nova lapela</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicar Podcast en YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Palabras clave</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nome de usuario de YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Contrasinal de Youtube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Ao facer clic en &apos;Descargar&apos; vostede certifica que posue tódolos dereitos sobre o contido ou que está autorizado por o propietario a publicar o contido en YouTube, e que éste cumple cos termos de servicio de YouTube que aparecen en&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Restablece as credenciais ao reiniciar</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Sobre fondo claro</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sobre fondo escuro</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidade</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Ancho de liña</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Forte</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fino</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>O bolígrafo é sensible á presión</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Mostrar vista previa do círculo de</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>Correo electrónico</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Documentos OpenBoard</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Data de creación</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Data de actualización</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Orde alfabética</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Orde de ordenación</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versión : …</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Configuración predeterminada</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Mostrar páxina con explorador externo</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Páxina de inicio:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclado virtual</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Tamaño das teclas do teclado:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de ferramentas</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Colocar na parte superior (recomendado para computadores tipo tablet)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Colocar na parte inferior (recomendado para encerados blancos)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Mostrar texto debaixo do botón</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paleta do lápiz</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígrafo</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Actualización do software</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Comprobar se hai actualizacións do software ao iniciarse</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenzas</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Mostrar o contido da páxina web nun monitor secundario ou proxector</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Pantalla múltiple</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Intercambiar control de pantalla e vista de pantalla</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalidade</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Comenzar en modalidade :</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Encerado</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Nome de usuario Proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Importar de Open-Sankoré</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Comprobe se os datos de Open-Sankoré se poden importar al iniciar</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Usar o teclado do sistema (recomendado)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Tamaño do botón do teclado virtual integrado</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Cuadrícula</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sobre fondo escuro</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidade</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Sobre fondo claro</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Intercambiar control de pantalla e vista de pantalla</translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Capturar elemento flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Seleccionar un flash para capturar</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nome da aplicación</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Crear aplicación</translation>
    </message>
</context>
</TS>
